@@ -6,13 +6,14 @@ import time
 from pathlib import Path
 from shutil import copyfile
 from time import sleep
+from typing import List, Tuple
 
 import click
 import yaml
 from click import MissingParameter, version_option
 
 from esque import __version__, validation
-from esque.cli.helpers import attrgetter, edit_yaml, ensure_approval, isatty
+from esque.cli.helpers import attrgetter, edit_yaml, ensure_approval, get_piped_stdin_arguments, isatty
 from esque.cli.options import State, default_options, output_format_option
 from esque.cli.output import (
     blue_bold,
@@ -372,7 +373,7 @@ def edit_offsets(state: State, consumer_id: str, topic_name: str):
     """
     logger = logging.getLogger(__name__)
     consumergroup_controller = ConsumerGroupController(state.cluster)
-    consumer_group_state, offset_plans = consumergroup_controller.read_current_consumergroup_offsets(
+    consumer_group_state, offset_plans = consumergroup_controller.read_current_consumer_group_offsets(
         consumer_id=consumer_id, topic_name_expression=topic_name if topic_name else ".*"
     )
     if consumer_group_state != "Empty":
@@ -413,14 +414,35 @@ def edit_offsets(state: State, consumer_id: str, topic_name: str):
         return
 
 
+@delete.command("consumergroup")
+@click.argument("consumergroup-id", required=False, type=click.STRING, autocompletion=list_consumergroups, nargs=-1)
+@default_options
+def delete_consumer_group(state: State, consumergroup_id: Tuple[str]):
+    """Delete consumer groups
+    """
+    consumer_groups = list(consumergroup_id) + get_piped_stdin_arguments()
+    consumergroup_controller: ConsumerGroupController = ConsumerGroupController(state.cluster)
+    current_consumergroups = consumergroup_controller.list_consumer_groups()
+    existing_consumer_groups: List[str] = []
+    for group in consumer_groups:
+        if group in current_consumergroups:
+            click.echo(f"Deleting {click.style(group, fg='green')}")
+            existing_consumer_groups.append(group)
+        else:
+            click.echo(f"Skipping {click.style(group, fg='yellow')} — does not exist")
+    if not existing_consumer_groups:
+        click.echo(click.style("The provided list contains no existing consumer groups.", fg="red"))
+    else:
+        if ensure_approval("Are you sure?", no_verify=state.no_verify):
+            consumergroup_controller.delete_consumer_groups(existing_consumer_groups)
+            current_consumergroups = consumergroup_controller.list_consumer_groups()
+            assert all(consumer_group not in current_consumergroups for consumer_group in existing_consumer_groups)
+        click.echo(click.style(f"Consumer groups '{existing_consumer_groups}' successfully deleted.", fg="green"))
+
+
 @delete.command("topic")
 @click.argument(
-    "topic-name",
-    metavar="TOPIC_NAME",
-    callback=fallback_to_stdin,
-    required=False,
-    type=click.STRING,
-    autocompletion=list_topics,
+    "topic-name", metavar="TOPIC_NAME", required=False, type=click.STRING, autocompletion=list_topics, nargs=-1
 )
 @default_options
 def delete_topic(state: State, topic_name: str):
@@ -428,13 +450,24 @@ def delete_topic(state: State, topic_name: str):
 
     WARNING: This command cannot be undone, and all data in the topic will be lost.
     """
+    topic_names = list(topic_name) + get_piped_stdin_arguments()
     topic_controller = state.cluster.topic_controller
-    if ensure_approval("Are you sure?", no_verify=state.no_verify):
-        topic_controller.delete_topic(Topic(topic_name))
-
-        assert topic_name not in (t.name for t in topic_controller.list_topics(get_topic_objects=False))
-
-    click.echo(click.style(f"Topic with name '{topic_name}' successfully deleted.", fg="green"))
+    current_topics = [topic.name for topic in topic_controller.list_topics(get_topic_objects=False)]
+    existing_topics: List[str] = []
+    for topic in topic_names:
+        if topic in current_topics:
+            click.echo(f"Deleting {click.style(topic, fg='green')}")
+            existing_topics.append(topic)
+        else:
+            click.echo(f"Skipping {click.style(topic, fg='yellow')} — does not exist")
+    if not existing_topics:
+        click.echo(click.style("The provided list contains no existing topics.", fg="red"))
+    else:
+        if ensure_approval("Are you sure?", no_verify=state.no_verify):
+            for topic_name in existing_topics:
+                topic_controller.delete_topic(Topic(topic_name))
+                assert topic_name not in (t.name for t in topic_controller.list_topics(get_topic_objects=False))
+            click.echo(click.style(f"Topics '{existing_topics}' successfully deleted.", fg="green"))
 
 
 @esque.command("apply")
@@ -557,7 +590,7 @@ def describe_topic(state: State, topic_name: str, consumers: bool, last_timestam
         consumergroups = [
             group_name
             for group_name in groups
-            if topic_name in consumergroup_controller.get_consumergroup(group_name).topics
+            if topic_name in consumergroup_controller.get_consumer_group(group_name).topics
         ]
 
         output_dict["consumergroups"] = consumergroups
@@ -602,7 +635,7 @@ def describe_broker(state: State, broker: str, output_format: str):
 
 
 @describe.command("consumergroup", short_help="Describe a consumer group.")
-@click.argument("consumer-id", callback=fallback_to_stdin, autocompletion=list_consumergroups, required=True)
+@click.argument("consumergroup-id", callback=fallback_to_stdin, autocompletion=list_consumergroups, required=True)
 @click.option(
     "--all-partitions",
     help="List status for all topic partitions instead of just summarizing each topic.",
@@ -611,10 +644,10 @@ def describe_broker(state: State, broker: str, output_format: str):
 )
 @output_format_option
 @default_options
-def describe_consumergroup(state: State, consumer_id: str, all_partitions: bool, output_format: str):
+def describe_consumergroup(state: State, consumergroup_id: str, all_partitions: bool, output_format: str):
     """Return information on group coordinator, offsets, watermarks, lag, and various metadata
     for consumer group CONSUMER_GROUP."""
-    consumer_group = ConsumerGroupController(state.cluster).get_consumergroup(consumer_id)
+    consumer_group = ConsumerGroupController(state.cluster).get_consumer_group(consumergroup_id)
     consumer_group_desc = consumer_group.describe(verbose=all_partitions)
 
     click.echo(format_output(consumer_group_desc, output_format))
@@ -644,11 +677,21 @@ def get_consumergroups(state: State, output_format: str):
 
 @get.command("topics")
 @click.option("-p", "--prefix", type=click.STRING, autocompletion=list_topics)
+@click.option(
+    "--hide-internal",
+    type=click.BOOL,
+    help="Hide internal topics in the output",
+    required=False,
+    default=False,
+    is_flag=True,
+)
 @output_format_option
 @default_options
-def get_topics(state: State, prefix: str, output_format: str):
+def get_topics(state: State, prefix: str, hide_internal: bool, output_format: str):
     """List all topics."""
-    topics = state.cluster.topic_controller.list_topics(search_string=prefix, get_topic_objects=False)
+    topics = state.cluster.topic_controller.list_topics(
+        search_string=prefix, get_topic_objects=False, hide_internal=hide_internal
+    )
     topic_names = [topic.name for topic in topics]
     click.echo(format_output(topic_names, output_format))
 
